@@ -25,6 +25,8 @@
 
 #include <glib.h>
 
+#include "vtemacros.h"
+
 G_BEGIN_DECLS
 
 /**
@@ -48,7 +50,7 @@ G_BEGIN_DECLS
  * The minor version number of the VTE library
  * (e.g. in version 3.1.4 this is 1).
  */
-#define VTE_MINOR_VERSION (42)
+#define VTE_MINOR_VERSION (52)
 
 /**
  * VTE_MICRO_VERSION:
@@ -56,7 +58,7 @@ G_BEGIN_DECLS
  * The micro version number of the VTE library
  * (e.g. in version 3.1.4 this is 4).
  */
-#define VTE_MICRO_VERSION (5)
+#define VTE_MICRO_VERSION (0)
 
 /**
  * VTE_CHECK_VERSION:
@@ -73,10 +75,13 @@ G_BEGIN_DECLS
    (VTE_MAJOR_VERSION == (major) && VTE_MINOR_VERSION > (minor)) || \
    (VTE_MAJOR_VERSION == (major) && VTE_MINOR_VERSION == (minor) && VTE_MICRO_VERSION >= (micro)))
 
+_VTE_PUBLIC
 guint vte_get_major_version (void) G_GNUC_CONST;
 
+_VTE_PUBLIC
 guint vte_get_minor_version (void) G_GNUC_CONST;
 
+_VTE_PUBLIC
 guint vte_get_micro_version (void) G_GNUC_CONST;
 
 G_END_DECLS
